# Agent Development Kit (ADK) Samples

[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](LICENSE)

<img src="https://github.com/google/adk-docs/blob/main/docs/assets/agent-development-kit.png" alt="Agent Development Kit Logo" width="150">

Welcome to the ADK Sample Agents repository! This collection provides ready-to-use agents built on top of the [Agent Development Kit](https://google.github.io/adk-docs/), designed to accelerate your development process. These agents cover a range of common use cases and complexities, from simple conversational bots to complex multi-agent workflows.

## ✨ Getting Started
This repo contains ADK sample agents for **Python**, **TypeScript**, **Go** and **Java.** Navigate to the **[Python](python/)**, **[TypeScript](typescript/)**, **[Go](go/)**, and **[Java](java/)** subfolders to see language-specific setup instructions, and learn more about the available sample agents.

> [!IMPORTANT]
> The agents in this repository are built using the **Agent Development Kit (ADK)**. Before you can run any of the samples, you must have the ADK installed. For instructions, please refer to the [**ADK Installation Guide**](https://google.github.io/adk-docs/get-started).

To learn more, check out the [ADK Documentation](https://google.github.io/adk-docs/), and the GitHub repositories for each language:
- [ADK Python](https://github.com/google/adk-python)
- [ADK Typescript](https://github.com/google/adk-js)
- [ADK Go](https://github.com/google/adk-go)
- [ADK Java](https://github.com/google/adk-java)

## 🌳 Repository Structure
```bash
├── go
│   ├── agents
│   │   ├── llm-auditor
│   └── README.md
├── java
│   ├── agents
│   │   ├── software-bug-assistant
│   │   └── time-series-forecasting
│   └── README.md
├── python
│   ├── agents
│   │   ├── academic-research
│   │   ├── antom-payment
│   │   ├── blog-writer
│   │   ├── brand-aligner
│   │   ├── brand-search-optimization
│   │   ├── camel
│   │   ├── customer-service
│   │   ├── data-engineering
│   │   ├── data-science
│   │   ├── financial-advisor
│   │   ├── fomc-research
│   │   ├── gemini-fullstack
│   │   ├── deep-search
│   │   ├── google-trends-agent
│   │   ├── image-scoring
│   │   ├── llm-auditor
│   │   ├── machine-learning-engineering
│   │   ├── marketing-agency
│   │   ├── medical-pre-authorization
│   │   ├── personalized-shopping
│   │   ├── plumber-data-engineering-assistant
│   │   ├── RAG
│   │   ├── realtime-conversational-agent
│   │   ├── safety-plugins
│   │   ├── short-movie-agents
│   │   ├── software-bug-assistant
│   │   ├── story_teller
│   │   ├── travel-concierge
│   │   └── README.md
│   └── README.md
├── typescript
│   ├── agents
│   │   ├── customer_service
│   └── README.md
└── README.md
```

## ℹ️ Getting help

If you have any questions or if you found any problems with this repository, please report through [GitHub issues](https://github.com/google/adk-samples/issues).

## 🤝 Contributing

We welcome contributions from the community! Whether it's bug reports, feature requests, documentation improvements, or code contributions, please see our [**Contributing Guidelines**](https://github.com/google/adk-samples/blob/main/CONTRIBUTING.md) to get started.

## 📄 License

This project is licensed under the Apache 2.0 License - see the [LICENSE](https://github.com/google/adk-samples/blob/main/LICENSE) file for details.

## Disclaimers

This is not an officially supported Google product. This project is not eligible for the [Google Open Source Software Vulnerability Rewards Program](https://bughunters.google.com/open-source-security).

This project is intended for demonstration purposes only. It is not intended for use in a production environment.
